var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  default: () => src_default
});
module.exports = __toCommonJS(src_exports);
var import_bundler_utils = require("@umijs/bundler-utils");
var import_utils = require("@umijs/utils");
var import_fs = __toESM(require("fs"));
var import_path = require("path");
var import_markdown = require("./markdown");
var src_default = (api) => {
  const locales = {};
  const localesPath = (0, import_path.join)(api.cwd, "docs/locales");
  if ((0, import_fs.existsSync)(localesPath)) {
    import_fs.default.readdirSync(localesPath).forEach((file) => {
      if (file.endsWith(".json")) {
        const filePath = (0, import_path.join)(localesPath, file);
        const content = import_fs.default.readFileSync(filePath).toString();
        const json = JSON.parse(content);
        const localeName = file.replace(".json", "");
        locales[localeName] = json;
      }
    });
  }
  api.modifyDefaultConfig((memo) => {
    memo.conventionRoutes = {
      ...memo.conventionRoutes,
      base: (0, import_path.join)(api.cwd, "docs")
    };
    memo.mdx = {
      loader: require.resolve("./loader"),
      loaderOptions: {}
    };
    return memo;
  });
  api.addLayouts(() => {
    return [
      {
        id: "docs-layout",
        file: withTmpPath({ api, path: "Layout.tsx" })
      }
    ];
  });
  api.onPatchRoute(({ route }) => {
    if (route.__content) {
      route.titles = (0, import_markdown.parseTitle)({
        content: route.__content
      });
    }
    if (route.file.match(/.[a-z]{2}-[A-Z]{2}.md$/)) {
      route.path = route.path.replace(/(.*).([a-z]{2}-[A-Z]{2})$/, "$2/$1");
      if (route.path.endsWith("README")) {
        route.path = route.path.replace(/README$/, "");
      }
    }
  });
  api.modifyRoutes((r) => {
    if (!locales)
      return r;
    for (const route in r) {
      if (r[route].path.match(/^[a-z]{2}-[A-Z]{2}\/.*/))
        continue;
      const defaultLangFile = r[route].file.replace(
        /(.[a-z]{2}-[A-Z]{2})?.md$/,
        ""
      );
      Object.keys(locales).map((l) => {
        if (r[defaultLangFile] && !r[defaultLangFile + "." + l]) {
          r[defaultLangFile + "." + l] = {
            ...r[defaultLangFile],
            path: `/${l}/${r[defaultLangFile].path}`
          };
        }
      });
    }
    return r;
  });
  api.onGenerateFiles(() => {
    var _a;
    let theme = ((_a = api.config.docs) == null ? void 0 : _a.theme) || require.resolve("../client/theme-doc/index.ts");
    if (theme === "blog") {
      theme = require.resolve("../client/theme-blog/index.ts");
    }
    theme = (0, import_utils.winPath)(theme);
    const themeConfigPath = (0, import_utils.winPath)((0, import_path.join)(api.cwd, "theme.config.ts"));
    const themeExists = (0, import_fs.existsSync)(themeConfigPath);
    let injectLocale = `themeConfig.locales = ${JSON.stringify(locales)};`;
    const [_, exports] = (0, import_bundler_utils.parseModuleSync)({
      content: (0, import_fs.readFileSync)(theme, "utf-8"),
      path: theme
    });
    api.writeTmpFile({
      path: "index.ts",
      content: `
export { ${exports.filter((item) => !item.startsWith("$")).join(", ")} } from '${(0, import_utils.winPath)(
        require.resolve("../client/theme-doc/index.ts")
      )}';
    `
    });
    api.writeTmpFile({
      path: "Layout.tsx",
      content: `
import React from 'react';
import { useOutlet, useAppData, useLocation, Link, history } from 'umi';
import { $Layout as Layout } from '${(0, import_utils.winPath)(
        require.resolve("../client/theme-doc/index.ts")
      )}';
${themeExists ? `import themeConfig from '${themeConfigPath}'` : `const themeConfig = {}`}

${injectLocale}

export default () => {
  const outlet = useOutlet();
  const appData = useAppData();
  const location = useLocation();
  return (
    <Layout appData={appData} components={{Link}} themeConfig={themeConfig} location={location} history={history}>
      <div>{ outlet }</div>
    </Layout>
  );
};
`
    });
  });
  api.chainWebpack((memo) => {
    if (api.env === "development") {
      memo.plugin("fastRefresh").tap(([params]) => [
        {
          ...params,
          include: /\.([cm]js|[jt]sx?|flow|md)$/i
        }
      ]);
    }
    return memo;
  });
};
function withTmpPath(opts) {
  return (0, import_path.join)(
    opts.api.paths.absTmpPath,
    opts.api.plugin.key && !opts.noPluginDir ? `plugin-${opts.api.plugin.key}` : "",
    opts.path
  );
}
